@@ -1,10 +1,9 @@
-#!/usr/bin/env python3
+#!/usr/bin/env python
 
 import sys
 import logging
 
-sys.path.insert(0, '/home/x/OneDrive/Projects/pyclui/src')
-from pyclui import Logger, DEBUG
+from xpycommon.log import Logger, DEBUG
 
 sys.path.insert(0, '/home/x/OneDrive/Projects/btl2cap/src')
 from btl2cap import CID_BR_EDR_SECURITY_MANAGER
